@@ -1,7 +1,7 @@
 package CPAN::Changes::Cwalitee::Core;
 
-our $DATE = '2019-07-08'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-07-10'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -394,11 +394,35 @@ sub indicator_english {
     [200, "OK", ''];
 }
 
+$SPEC{indicator_no_duplicate_version} = {
+    v => 1.1,
+    summary => 'Versions are unique',
+    args => {
+    },
+};
+sub indicator_no_duplicate_version {
+    require Data::Cmp;
+    require List::Util;
+
+    my %args = @_;
+    my $r = $args{r};
+
+    my $p = $r->{parsed};
+    defined $p or return [412];
+
+    my @vers = sort map { $_->{version} } @{ $p->{_releases_array} // [] };
+    my @uniq_vers = List::Util::uniq(@vers);
+    if (Data::Cmp::cmp_data(\@vers, \@uniq_vers) == 0) {
+        return [200, "OK", ''];
+    } else {
+        return [200, "OK", "There are some duplicate versions"];
+    }
+}
+
 # TODO: indicator_sufficient_entries_length
 # TODO: indicator_version_correct_format
 # TODO: indicator_not_commit_logs
 # TODO: indicator_name_preferred (e.g. Changes and not ChangeLog.txt)
-# TODO: indicator_no_duplicate_version
 # TODO: indicator_preamble_not_template
 # TODO: indicator_entries_not_template
 # TODO: indicator_entries_english_tense_consistent (all past tense, or all present tense)
@@ -420,7 +444,7 @@ CPAN::Changes::Cwalitee::Core - A collection of core indicators for CPAN Changes
 
 =head1 VERSION
 
-This document describes version 0.004 of CPAN::Changes::Cwalitee::Core (from Perl distribution CPAN-Changes-Cwalitee), released on 2019-07-08.
+This document describes version 0.005 of CPAN::Changes::Cwalitee::Core (from Perl distribution CPAN-Changes-Cwalitee), released on 2019-07-10.
 
 =head1 FUNCTIONS
 
@@ -514,6 +538,31 @@ Return value:  (any)
 
 
 
+=head2 indicator_no_duplicate_version
+
+Usage:
+
+ indicator_no_duplicate_version() -> [status, msg, payload, meta]
+
+Versions are unique.
+
+This function is not exported.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 indicator_no_empty_group
 
 Usage:
